/**
 * Copyright (c) 2016-2017 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.samples.rest.edm.dropwizard.server.repository;

import java.util.Map;
import java.util.concurrent.ConcurrentHashMap;
import java.util.concurrent.atomic.AtomicLong;

import javax.activation.DataHandler;
import javax.validation.constraints.NotNull;

import org.ow2.petals.samples.rest.edm.dropwizard.server.data.Metadatas;

public class Repository {

    private final Map<String, Metadatas> metadatas = new ConcurrentHashMap<>();

    private final Map<String, DataHandler> documents = new ConcurrentHashMap<>();

    private final AtomicLong idSequence = new AtomicLong();

    public Metadatas getMetadatas(final String docReference) {
        return this.metadatas.get(docReference);
    }

    public DataHandler getDocument(@NotNull final String docReference) {
        return this.documents.get(docReference);
    }

    public String addDocument(@NotNull final DataHandler documentDh, @NotNull final Metadatas metadatas) {
        final String docReference = String.valueOf(this.idSequence.incrementAndGet());
        this.documents.put(docReference, documentDh);
        this.metadatas.put(docReference, metadatas);
        return docReference;
    }

    /**
     * @return {@code true} if the requested document exists, {@code false} otherwise
     */
    public boolean replaceMetadatas(@NotNull final String reference, @NotNull final Metadatas metadatas) {
        return this.metadatas.put(reference, metadatas) != null;
    }

    /**
     * @return {@code true} if the requested document exists, {@code false} otherwise
     */
    public boolean delete(@NotNull final String reference) {
        this.metadatas.remove(reference);
        return this.documents.remove(reference) != null;
    }

}
