/**
 * Copyright (c) 2016-2017 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.samples.rest.edm.dropwizard.server.resources;

import java.util.Map;

import javax.annotation.security.PermitAll;
import javax.annotation.security.RolesAllowed;
import javax.validation.Valid;
import javax.validation.constraints.NotNull;
import javax.ws.rs.Consumes;
import javax.ws.rs.GET;
import javax.ws.rs.PUT;
import javax.ws.rs.Path;
import javax.ws.rs.PathParam;
import javax.ws.rs.Produces;
import javax.ws.rs.core.MediaType;
import javax.ws.rs.core.Response;
import javax.ws.rs.core.Response.Status;

import org.ow2.petals.samples.rest.edm.dropwizard.server.data.Metadatas;
import org.ow2.petals.samples.rest.edm.dropwizard.server.repository.Repository;

@Path("/library/{library}/document/{reference}/metadata")
public class DocumentMetadataResource {

    private final Map<String, Repository> docRepositories;

    public DocumentMetadataResource(final Map<String, Repository> docRepositories) {
        this.docRepositories = docRepositories;
    }

    @GET
    @Produces({ MediaType.APPLICATION_JSON, MediaType.APPLICATION_XML })
    @PermitAll
    public Response getMetadatas(@PathParam("library") final String library,
            @PathParam("reference") final String reference) {

        final Repository docRepository = this.docRepositories.get(library);
        if (docRepository != null) {
            final Metadatas metadatas = docRepository.getMetadatas(reference);
            if (metadatas != null) {
                return Response.ok(metadatas).build();
            } else {
                // The requested document does not exist
                return Response.status(Status.NOT_FOUND).build();
            }
        } else {
            // The requested library does not exist
            return Response.status(Status.NOT_FOUND).build();
        }
    }

    @PUT
    @RolesAllowed("ADMIN_DOC")
    @Consumes({ MediaType.APPLICATION_JSON, MediaType.APPLICATION_XML })
    public Response replaceAllMetadatas(@PathParam("library") final String library,
            @PathParam("reference") final String reference, @NotNull @Valid final Metadatas newMetadatas) {

        final Repository docRepository = this.docRepositories.get(library);
        if (docRepository != null) {
            if (docRepository.replaceMetadatas(reference, newMetadatas)) {
                return Response.ok().build();
            } else {
                // The requested document does not exist
                return Response.status(Status.NOT_FOUND).build();
            }
        } else {
            // The requested library does not exist
            return Response.status(Status.NOT_FOUND).build();
        }
    }
}
