/**
 * Copyright (c) 2017 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.samples.rest.edm.operation;

import static org.ow2.petals.binding.rest.junit.Assert.assertJBIFault;
import static org.ow2.petals.binding.rest.junit.Assert.assertJBIOutResponse;

import javax.ws.rs.core.MediaType;

import org.apache.http.HttpStatus;
import org.junit.ClassRule;
import org.junit.Test;
import org.ow2.petals.binding.rest.junit.rule.ServiceOperationUnderTest;
import org.ow2.petals.samples.rest.edm.AbstractTest;
import org.ow2.petals.samples.rest.edm.Constants;

/**
 * Test unitaire de l'opération {@code consulter}
 * 
 * @author Christophe DENEUX - Linagora
 *
 */
public class GetMetadataByJsonOpTest extends AbstractTest implements Constants {

    @ClassRule
    public static final ServiceOperationUnderTest OPERATION_UNDER_TEST = new ServiceOperationUnderTest(
            OP_GET_METADATA_BY_JSON);

    /**
     * Check the JBI response of operation {@value OP_GET_METADATA_BY_JSON} when a REST response is returned with HTTP
     * status 200 and contains metadatas.
     */
    @Test
    public void nominal() throws Exception {
        assertJBIOutResponse("get-metadata-expected-nominal-response.xml", OPERATION_UNDER_TEST,
                HttpStatus.SC_OK, null, "get-metadata-nominal-http-body.json",
                MediaType.APPLICATION_JSON_TYPE, null);
    }

    /**
     * Check the JBI response of operation {@value OP_GET_METADATA_BY_JSON} when a REST response is returned with HTTP
     * status 200 and contains no metadata.
     */
    @Test
    public void nometadata() throws Exception {
        assertJBIOutResponse("get-metadata-expected-no-metadata-response.xml", OPERATION_UNDER_TEST,
                HttpStatus.SC_OK, null, "get-metadata-no-metadata-http-body.json",
                MediaType.APPLICATION_JSON_TYPE, null);
    }

    /**
     * Check the JBI response of operation {@value OP_GET_METADATA_BY_JSON} when a REST response is returned with HTTP
     * status 404 (unexisting document)
     */
    @Test
    public void unexistingDocument() throws Exception {

        assertJBIFault("get-metadata-expected-fault-unexisting-document.xml", OPERATION_UNDER_TEST,
                HttpStatus.SC_NOT_FOUND, null, null, null, "get-metadata-by-json-request.xml", null);
    }

}
