/**
 * Copyright (c) 2017 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.samples.rest.edm.operation;

import static org.ow2.petals.binding.rest.junit.Assert.assertJBIRequestJSON;

import java.util.HashMap;
import java.util.Map;

import org.junit.BeforeClass;
import org.junit.ClassRule;
import org.junit.Test;
import org.ow2.petals.binding.rest.junit.rule.ServiceOperationUnderTest;
import org.ow2.petals.component.framework.api.Message.MEPConstants;
import org.ow2.petals.samples.rest.edm.AbstractTest;
import org.ow2.petals.samples.rest.edm.Constants;

/**
 * Test unitaire de l'opération {@code consulter}
 * 
 * @author Christophe DENEUX - Linagora
 *
 */
public class ResetMetadatasByJsonOpTest extends AbstractTest implements Constants {

    @ClassRule
    public static final ServiceOperationUnderTest OPERATION_UNDER_TEST = new ServiceOperationUnderTest(
            OP_RESET_METADATAS_BY_JSON);

    public static Map<String, String> URI_PARAMETERS;

    @BeforeClass
    public static void createUriParameters() {
        URI_PARAMETERS = new HashMap<>();
        URI_PARAMETERS.put("library", "my-library");
        URI_PARAMETERS.put("reference", "my-ref");
    }

    /**
     * Check the HTTP Rest request of operation {@value OP_RESET_METADATAS_BY_JSON} when a JBI requett is received and
     * contains metadatas.
     */
    @Test
    public void requestWithMetadata() throws Exception {

        assertJBIRequestJSON("reset-metadatas-by-json-with-metadatas-expected-request.json", OPERATION_UNDER_TEST,
                MEPConstants.IN_OUT_PATTERN, "reset-metadatas-by-json-with-metadatas-request.xml", URI_PARAMETERS);
    }

    /**
     * Check the HTTP Rest request of operation {@value OP_RESET_METADATAS_BY_JSON} when a JBI request is received and
     * contains no metadatas.
     */
    @Test
    public void requestWithoutMetadata() throws Exception {

        assertJBIRequestJSON("reset-metadatas-by-json-without-metadatas-expected-request.json", OPERATION_UNDER_TEST,
                MEPConstants.IN_OUT_PATTERN, "reset-metadatas-by-json-without-metadatas-request.xml", URI_PARAMETERS);
    }

}
